@@ -7,9 +7,8 @@
 #' @import dplyr
 #' @import reshape2
 #' @import ggplot2
-#' @import lme4
 #' @import agricolae
-#' @param res an object created by \code{qpcrANOVA(x)} function on a two factor data such as \code{data_2factor}.
+#' @param res the FC data frame created by \code{qpcrANOVA(x)$Result} function on a two factor data such as \code{data_2factor}.
 #' @param x.axis.factor x-axis factor.
 #' @param group.factor grouping factor.
 #' @param width a positive number determining bar width.
@@ -17,7 +16,6 @@
 #' @param y.axis.adjust  a negative or positive number for reducing or increasing the length of the y axis.
 #' @param y.axis.by determines y axis step length.
 #' @param show.errorbars show errorbars
-#' @param show.points show points
 #' @param errorbar Type of error bar, can be \code{se} or \code{ci}.
 #' @param letter.position.adjust adjust the distance between the grouping letters to the error bars.
 #' @param xlab  the title of the x axis.
@@ -35,8 +33,7 @@
 #' data_2factor
 #'
 #' # Before generating plot, the result table needs to be extracted as below:
-#' res <- qpcrANOVA(data_2factor, numberOfrefGenes = 1)
-#' res
+#' res <- qpcrANOVA(data_2factor, numberOfrefGenes = 1)$Result
 #'
 #' # Plot of the 'res' data with 'Genotype' as grouping factor
 #' twoFACTORplot(res,
@@ -48,21 +45,18 @@
 #'    y.axis.by = 2,
 #'    ylab = "Relative Expression",
 #'    xlab = "Drought Levels",
-#'    show.letters = TRUE, 
 #'    letter.position.adjust = 0.2,
 #'    legend.position = c(0.2, 0.8),
 #'    errorbar = "se")
 #'
 #' # Plotting the same data with 'Drought' as grouping factor
 #' twoFACTORplot(res,
-#'    x.axis.factor = Genotype,
-#'    group.factor = Drought,
-#'    xlab = "Genotype",
-#'    fill = "Blues",
-#'    fontsize = 12,
-#'    show.letters = FALSE,
-#'    show.points = TRUE,
-#'    show.errorbars = FALSE)
+#'               x.axis.factor = Genotype,
+#'               group.factor = Drought,
+#'               xlab = "Genotype",
+#'               fill = "Blues",
+#'               fontsizePvalue = 5,
+#'               errorbar = "ci")
 #'
 #'
 
@@ -79,7 +73,6 @@ twoFACTORplot <- function(res,
                           show.errorbars = TRUE,
                           errorbar = "se",
                           show.letters = TRUE,
-                          show.points = FALSE,
                           letter.position.adjust = 0.1,
                           ylab = "Relative Expression",
                           xlab = "none",
@@ -88,14 +81,15 @@ twoFACTORplot <- function(res,
                           fontsizePvalue = 7,
                           axis.text.x.angle = 0,
                           axis.text.x.hjust = 0.5){
-  b <- res$Result
-  a <- res$Final_data
-  RE <- b$RE
+  b <- res
   se <- b$se
   LCL <- b$LCL
   UCL <- b$UCL
-  wDCt <- a$wDCt
   
+  
+  if (any(grepl("RE", names(b)))) {
+    RE <- b$RE
+    
   qq1 <- ggplot(b, aes(factor({{x.axis.factor}}, levels = as.character(unique({{x.axis.factor}}))),
                        y = RE, group = {{ group.factor }}, fill = {{ group.factor }})) +
     geom_col(color = "black", position = "dodge", width = width) +
@@ -106,12 +100,12 @@ twoFACTORplot <- function(res,
     theme(axis.text.x = element_text(size = fontsize, color = "black", angle = axis.text.x.angle, hjust = axis.text.x.hjust),
           axis.text.y = element_text(size = fontsize, color = "black", angle = 0, hjust = 0.5),
           axis.title  = element_text(size = fontsize),
-          legend.text = element_text(size = fontsize)) +
+          legend.text = element_text(size = fontsize),
+          legend.background = element_rect(fill = "transparent")) +
     scale_y_continuous(breaks = seq(0, max(RE) + max(se) + y.axis.adjust, by = y.axis.by), 
                        limits = c(0, max(RE) + max(se) + y.axis.adjust), expand = c(0, 0)) +
     theme(legend.position  = legend.position) +
-    theme(legend.title = element_text(size = fontsize, color = "black"),
-          legend.background = element_rect(fill = "transparent")) 
+    theme(legend.title = element_text(size = fontsize, color = "black")) 
   
   
   if (show.errorbars) {
@@ -120,12 +114,6 @@ twoFACTORplot <- function(res,
   }
   
   
-  if (show.points) {
-    qq1 <-qq1 + 
-    geom_point(data = a, aes(x = factor({{x.axis.factor}}, levels = as.character(unique({{x.axis.factor}}))), 
-                             y = (2^(-wDCt)), group = as.factor({{ group.factor }}), fill = as.factor({{ group.factor }})), 
-               position = position_dodge(width = width),color = "grey30",  fill = "grey30", shape = 21, size = 2)
-  }
   if (show.letters) {
     qq1 <-qq1 + 
       geom_text(data = b, aes(label = letters, x = {{ x.axis.factor }}, y = RE + se + letter.position.adjust), 
@@ -151,7 +139,8 @@ twoFACTORplot <- function(res,
     theme(axis.text.x = element_text(size = fontsize, color = "black", angle = axis.text.x.angle, hjust = axis.text.x.hjust),
           axis.text.y = element_text(size = fontsize, color = "black", angle = 0, hjust = 0.5),
           axis.title  = element_text(size = fontsize),
-          legend.text = element_text(size = fontsize)) +
+          legend.text = element_text(size = fontsize),
+          legend.background = element_rect(fill = "transparent")) +
     scale_y_continuous(breaks = seq(0, max(RE) + max(LCL) + y.axis.adjust, by = y.axis.by), 
                        limits = c(0, max(RE) + max(LCL) + y.axis.adjust), expand = c(0, 0)) +
     theme(legend.position  = legend.position) +
@@ -163,12 +152,7 @@ twoFACTORplot <- function(res,
       geom_errorbar(aes(ymin = LCL, ymax = UCL), width = 0.2, position = position_dodge(width = 0.5))
   }
   
-  if (show.points) {
-    qq2 <-qq2 + 
-      geom_point(data = a, aes(x = factor({{x.axis.factor}}, levels = as.character(unique({{x.axis.factor}}))), 
-                               y = (2^(-wDCt)), group = as.factor({{ group.factor }}), fill = as.factor({{ group.factor }})), 
-                 position = position_dodge(width = width),color = "grey30",  fill = "grey30", shape = 21, size = 3)
-  }
+
   if (show.letters) {
     qq2 <- qq2 + 
       geom_text(data = b, aes(label = letters, x = {{ x.axis.factor }}, y = UCL + letter.position.adjust), 
@@ -190,8 +174,108 @@ twoFACTORplot <- function(res,
   } else if(errorbar == "ci") {
     out2 <- list(plot = qq2)
   }
+  }
+  
+  
+  
+  
+  
+  
+  
+  if (any(grepl("FC", names(b)))) {
+    x$FC <- as.numeric(x$FC)
+    letters <- x$sig
+    FC <- b$FC
+    
+    qq1 <- ggplot(b, aes(factor({{x.axis.factor}}, levels = as.character(unique({{x.axis.factor}}))),
+                         y = FC, group = {{ group.factor }}, fill = {{ group.factor }})) +
+      geom_col(color = "black", position = "dodge", width = width) +
+      scale_fill_brewer(palette = fill) +
+      #geom_hline(aes(yintercept = 1), col = "red", linetype = 2, show.legend = FALSE)  +
+      ylab(ylab) +
+      theme_bw() +
+      theme(axis.text.x = element_text(size = fontsize, color = "black", angle = axis.text.x.angle, hjust = axis.text.x.hjust),
+            axis.text.y = element_text(size = fontsize, color = "black", angle = 0, hjust = 0.5),
+            axis.title  = element_text(size = fontsize),
+            legend.text = element_text(size = fontsize)) +
+      scale_y_continuous(breaks = seq(0, max(FC) + max(se) + y.axis.adjust, by = y.axis.by), 
+                         limits = c(0, max(FC) + max(se) + y.axis.adjust), expand = c(0, 0)) +
+      theme(legend.position  = legend.position) +
+      theme(legend.title = element_text(size = fontsize, color = "black"),
+            legend.background = element_rect(fill = "transparent")) 
+    
+    
+    if (show.errorbars) {
+      qq1 <-qq1 +
+        geom_errorbar(aes(ymin = FC, ymax = FC + se), width = 0.2, position = position_dodge(width = 0.5))
+    }
+    
+    
+    if (show.letters) {
+      qq1 <-qq1 + 
+        geom_text(data = b, aes(label = letters, x = {{ x.axis.factor }}, y = FC + se + letter.position.adjust), 
+                  vjust = -0.5, size = fontsizePvalue, position = position_dodge(width = 0.5))
+    }
+    
+    if(xlab == "none"){
+      qq1 <- qq1 + 
+        labs(x = NULL)
+    }else{
+      qq1 <- qq1 +
+        xlab(xlab)
+    }
+    
+    
+    qq2 <- ggplot(b, aes(factor({{x.axis.factor}}, levels = as.character(unique({{x.axis.factor}}))),
+                         y = FC, group = {{ group.factor }}, fill = {{ group.factor }})) +
+      geom_col(color = "black", position = "dodge", width = width) +
+      scale_fill_brewer(palette = fill) +
+      #geom_hline(aes(yintercept = 1), col = "red", linetype = 2, show.legend = FALSE) +
+      ylab(ylab) +
+      theme_bw() +
+      theme(axis.text.x = element_text(size = fontsize, color = "black", angle = axis.text.x.angle, hjust = axis.text.x.hjust),
+            axis.text.y = element_text(size = fontsize, color = "black", angle = 0, hjust = 0.5),
+            axis.title  = element_text(size = fontsize),
+            legend.text = element_text(size = fontsize),
+            legend.background = element_rect(fill = "transparent")) +
+      scale_y_continuous(breaks = seq(0, max(FC) + max(LCL) + y.axis.adjust, by = y.axis.by), 
+                         limits = c(0, max(FC) + max(LCL) + y.axis.adjust), expand = c(0, 0)) +
+      theme(legend.position  = legend.position) +
+      theme(legend.title = element_text(size = fontsize, color = "black")) 
+    
+    
+    if (show.errorbars) {
+      qq2 <-qq2 +
+        geom_errorbar(aes(ymin = LCL, ymax = UCL), width = 0.2, position = position_dodge(width = 0.5))
+    }
+    
+    
+    if (show.letters) {
+      qq2 <- qq2 + 
+        geom_text(data = b, aes(label = letters, x = {{ x.axis.factor }}, y = UCL + letter.position.adjust), 
+                  vjust = -0.5, size = fontsizePvalue, position = position_dodge(width = 0.5))
+    }
+    
+    if(xlab == "none"){
+      qq2 <- qq2 + 
+        labs(x = NULL)
+    }else{
+      qq2 <- qq2 +
+        xlab(xlab)
+    }
+    
+    
+    if(errorbar == "se") {
+      out2 <- list(plot = qq1)
+      
+    } else if(errorbar == "ci") {
+      out2 <- list(plot = qq2)
+    }
+  }
+  
   
   return(out2)
 }
 
 
+
